==> huaweicloudsdkworkspace-3.1.87-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_user_groups_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListUserGroupsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_count': 'int',
        'user_groups': 'list[UserGroupInfo]'
    }

    attribute_map = {
        'total_count': 'total_count',
        'user_groups': 'user_groups'
    }

    def __init__(self, total_count=None, user_groups=None):
        """ListUserGroupsResponse

        The model defined in huaweicloud sdk

        :param total_count: 满足条件的用户组总数。
        :type total_count: int
        :param user_groups: 用户组列表。
        :type user_groups: list[:class:`huaweicloudsdkworkspace.v2.UserGroupInfo`]
        """
        
        super(ListUserGroupsResponse, self).__init__()

        self._total_count = None
        self._user_groups = None
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if user_groups is not None:
            self.user_groups = user_groups

    @property
    def total_count(self):
        """Gets the total_count of this ListUserGroupsResponse.

        满足条件的用户组总数。

        :return: The total_count of this ListUserGroupsResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListUserGroupsResponse.

        满足条件的用户组总数。

        :param total_count: The total_count of this ListUserGroupsResponse.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def user_groups(self):
        """Gets the user_groups of this ListUserGroupsResponse.

        用户组列表。

        :return: The user_groups of this ListUserGroupsResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.UserGroupInfo`]
        """
        return self._user_groups

    @user_groups.setter
    def user_groups(self, user_groups):
        """Sets the user_groups of this ListUserGroupsResponse.

        用户组列表。

        :param user_groups: The user_groups of this ListUserGroupsResponse.
        :type user_groups: list[:class:`huaweicloudsdkworkspace.v2.UserGroupInfo`]
        """
        self._user_groups = user_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListUserGroupsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_user_groups_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListUserGroupsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_count': 'int',
        'user_groups': 'list[UserGroupInfo]'
    }

    attribute_map = {
        'total_count': 'total_count',
        'user_groups': 'user_groups'
    }

    def __init__(self, total_count=None, user_groups=None):
        r"""ListUserGroupsResponse

        The model defined in huaweicloud sdk

        :param total_count: 满足条件的用户组总数。
        :type total_count: int
        :param user_groups: 用户组列表。
        :type user_groups: list[:class:`huaweicloudsdkworkspace.v2.UserGroupInfo`]
        """
        
        super(ListUserGroupsResponse, self).__init__()

        self._total_count = None
        self._user_groups = None
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if user_groups is not None:
            self.user_groups = user_groups

    @property
    def total_count(self):
        r"""Gets the total_count of this ListUserGroupsResponse.

        满足条件的用户组总数。

        :return: The total_count of this ListUserGroupsResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        r"""Sets the total_count of this ListUserGroupsResponse.

        满足条件的用户组总数。

        :param total_count: The total_count of this ListUserGroupsResponse.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def user_groups(self):
        r"""Gets the user_groups of this ListUserGroupsResponse.

        用户组列表。

        :return: The user_groups of this ListUserGroupsResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.UserGroupInfo`]
        """
        return self._user_groups

    @user_groups.setter
    def user_groups(self, user_groups):
        r"""Sets the user_groups of this ListUserGroupsResponse.

        用户组列表。

        :param user_groups: The user_groups of this ListUserGroupsResponse.
        :type user_groups: list[:class:`huaweicloudsdkworkspace.v2.UserGroupInfo`]
        """
        self._user_groups = user_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListUserGroupsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
